@@ -3,27 +3,27 @@
 import sys
 import yaml
 import os
-import argparse
-import time
 import requests
 from requests.packages.urllib3.exceptions import InsecureRequestWarning  # suppressing 'Unverified HTTPS request' msg
 import json
 
-from colorama import Fore, Back, Style
+from colorama import Fore, Style
 
 requests.packages.urllib3.disable_warnings(InsecureRequestWarning)       # suppressing 'Unverified HTTPS request' msg
 
 def get_url(conf):
   if 'dev' in conf['api']:
     base_url='http://localhost:8086/v2.0/projects/'
+  elif 'staging' in conf['api']:
+    base_url='https://api.localizestaging.com/v2.0/projects/'
   else:
     base_url='https://api.localizejs.com/v2.0/projects/'
 
   return base_url+conf['api']['project']+'/resources'
 
 def config():
-  project = raw_input('Localize project key [None]: ')
-  token = raw_input('Localize API token [None]: ')
+  project = input('Localize project key [None]: ')
+  token = input('Localize API token [None]: ')
 
   data = dict(
     api = dict(
@@ -31,6 +31,7 @@ def config():
       token = token
     ),
     format = 'format',
+    type = 'phrase',
     push = dict(
       sources = [dict(file = '/full/path/to/your/language_code.format_extension')]
     ),
@@ -52,10 +53,33 @@ def config():
   with open(config_file, 'w+') as out:
     out.write(yaml.dump(data, default_flow_style=False))
 
-def push(conf):
+def push(conf, profile):
   errors = []
   skip = 0
-  for source in conf['push']['sources']:
+
+  if profile and not profile in conf['push']:
+    sys.exit(Fore.RED + 'Could not find matching config. Please make sure you specified the right name in --config.' + Style.RESET_ALL)
+
+  if profile and not 'sources' in conf['push'][profile]:
+    sys.exit(Fore.RED + 'Could not find any sources to push in the config set. Please make sure your configuration is formed correctly.' + Style.RESET_ALL)
+
+  if not 'sources' in conf['push']:
+    sys.exit(Fore.RED + 'Could not find any sources to push. Please make sure your configuration is formed correctly.' + Style.RESET_ALL)
+
+  # Assume pushing phrases unless specified in config_file
+  if profile and 'type' in conf['push'][profile]:
+    type = conf['push'][profile]['type']
+  elif 'type' in conf:
+    type = conf['type']
+  else:
+    type = 'phrase'
+
+  if profile and 'sources' in conf['push'][profile]:
+    sourceFiles = conf['push'][profile]['sources']
+  else:
+    sourceFiles = conf['push']['sources']
+
+  for source in sourceFiles:
     url = get_url(conf)
     headers={ 'Authorization': 'Bearer ' + conf['api']['token'] }
 
@@ -73,13 +97,15 @@ def push(conf):
       file = open(source['file'], 'rb')
     except (IOError, OSError):
       skip =+ 1
-      print(Fore.RED + 'Skipping import of ' + language + '. No target file path in the localize cli config.yml')
+      print(Fore.RED + 'Skipping import of ' + language + '. No target file path in the localize cli config.yml' + Style.RESET_ALL)
       continue
 
     content={ 'content': file }
 
     data={
       'language': language,
+      'type': type,
+      'origin': 'cli',
       'format': format.replace('yml','yaml').upper()  # replacing 'yml' file format to 'yaml'
     }
 
@@ -99,17 +125,34 @@ def push(conf):
     for error in errors:
       print(Fore.RED+error+Style.RESET_ALL)
   else:
-    sys.exit(Fore.GREEN + 'Successfully pushed ' + str(len(conf['push']['sources'])-skip) + ' file(s) to Localize!' + Style.RESET_ALL)
+    print(Fore.GREEN + 'Successfully pushed ' + str(len(conf['push']['sources'])-skip) + ' file(s) to Localize!' + Style.RESET_ALL)
 
-def pull(conf):
+def pull(conf, profile):
   errors = []
+  if profile and not profile in conf['pull']:
+    sys.exit(Fore.RED + 'Could not find matching config. Please make sure you specified the right name in --config.' + Style.RESET_ALL)
+
+  if profile and not 'targets' in conf['pull'][profile]:
+    sys.exit(Fore.RED + 'Could not find any targets to pull in the config set. Please make sure your configuration is formed correctly.' + Style.RESET_ALL)
 
   if not 'targets' in conf['pull']:
     sys.exit(Fore.RED + 'Could not find any targets to pull. Please make sure your configuration is formed correctly.' + Style.RESET_ALL)
 
   skip = 0
 
-  for target in conf['pull']['targets']:
+  # Assume pulling phrases unless specified in config_file
+  if profile and 'type' in conf['pull'][profile]:
+    type = conf['pull'][profile]['type']
+  elif 'type' in conf:
+    type = conf['type']
+  else:
+    type = 'phrase'
+
+  if profile and 'targets' in conf['pull'][profile]:
+    targetFiles = conf['pull'][profile]['targets']
+  else:
+    targetFiles = conf['pull']['targets']
+  for target in targetFiles:
     if not target:
       sys.exit(Fore.RED + 'Could not find target.' + Style.RESET_ALL)
 
@@ -124,13 +167,14 @@ def pull(conf):
     else:
       format = conf['format']
 
-    file = target.values()[0]
+    file = list(target.values())[0]
 
     # Use the key as the language
-    language = target.keys()[0]
+    language =  list(target.keys())[0]
 
     data={
       'language': language,
+      'type': type,
       'format': format.replace('yml','yaml').upper(),    # replacing 'yml' file format to 'yaml
       'filter': 'has-active-translations'
     }
@@ -154,7 +198,7 @@ def pull(conf):
               file.write(chunk)
       except IOError:
         skip =+ 1
-        print(Fore.RED + 'Skipping export of ' + language + '. No target file path in the localize cli config.yml')
+        print(Fore.RED + 'Skipping export of ' + language + '. No target file path in the localize cli config.yml' + Style.RESET_ALL)
 
   # If there are any errors display them to the user
   if errors:
